Index: src/x64/builtins-x64.cc |
diff --git a/src/x64/builtins-x64.cc b/src/x64/builtins-x64.cc |
index 30c1a51ac6d12e71af47a6d79b1a5848ce405b9d..18c65b1db852b3262c9f9d09315c357317b704c1 100644 |
--- a/src/x64/builtins-x64.cc |
+++ b/src/x64/builtins-x64.cc |
@@ -353,9 +353,9 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm, |
__ JumpIfSmi(rax, &use_receiver); |
// If the type of the result (stored in its map) is less than |
- // FIRST_SPEC_OBJECT_TYPE, it is not an object in the ECMA sense. |
- STATIC_ASSERT(LAST_SPEC_OBJECT_TYPE == LAST_TYPE); |
- __ CmpObjectType(rax, FIRST_SPEC_OBJECT_TYPE, rcx); |
+ // FIRST_JS_RECEIVER_TYPE, it is not an object in the ECMA sense. |
+ STATIC_ASSERT(LAST_JS_RECEIVER_TYPE == LAST_TYPE); |
+ __ CmpObjectType(rax, FIRST_JS_RECEIVER_TYPE, rcx); |
__ j(above_equal, &exit); |
// Throw away the result of the constructor invocation and use the |